@@ -9,17 +9,18 @@ __data_replace={
     "${header2}": "Omega Mega table",
     "${text}": "Value of the project",
     "${chart_title}": "Something new",
+    "${nume_client}":"pyadvdocx"
 }
 
 
 def main():
-    docx_path=os.path.join(os.path.curdir,"test","data","Text_Replace.docx")
-    docx_path_done=os.path.join(os.path.curdir,"test","data","Text_Replace_done.docx")
+    docx_path=os.path.join(os.getcwd(),"test","data","venv_s2_input - Copy.docx")
+    docx_path_done=os.path.join(os.getcwd(),"test","data","venv_s2_input_done.docx")
     __doc_obj=Document(docx_path)
-    print(pyadvdocx_text.replace(docx=__doc_obj,**__data_replace))
+    __docx_obj=pyadvdocx_text.replace(docx=__doc_obj,**__data_replace)
 
 
-    __doc_obj.save(docx_path_done)
+    __docx_obj.save(docx_path_done)
 
 
 
